Description Usage Arguments Details Value See Also
Compute the Cartesian Square of a data frame or a tibble.
1 | CartesianSquare(x, ...)
|
x |
A data frame or |
... |
Unquoted names of variables in |
This is a thin wrapper for crossing that also performs
some string formatting on the column names of the data frame or tibble.
A tibble whose rows denote the values of the
Cartesian production of x with itself. If x has n
columns, then the returned Cartesian square has 2n columns: columns
1, ..., n are the column names of x with _i appended;
columns n+1, ..., 2n are the column names of x with
_j appended.
crossing for a description of how the rows of
the Cartesian square are ordered.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.