Description Usage Arguments Value
Compute the Laplacian-Eigenmaps embedding of a weighted adjacency matrix.
1 | LaplacianEigenmaps(w, symmetric = FALSE)
|
w |
A symmetric weighted adjacency matrix. |
symmetric |
A logical. If |
The eigenvalues lambda and corresponding eigenvectors e
that are solutions to the generalized eigenvector problem:
L(w)*f = lambda*D(w)*e.
The eigenvalues and eigenvectors are returned as a list with two elements:
values: a numeric vector of the eigenvalues, in increasing
order.
vectors: a tibble with columns
x, e1, ..., eN, where N is the number of rows in the
input matrix w. The column x contains the row names of
w. The columns e1, ..., eN are the eigenvectors associated
with the eigenvalues (e.g., vectors$e1 is associated with
values[1]). Columns e2, ..., eJ give an embedding, in
J-1-dimensinal space, for the data identified by x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.